==> aria2_1.1.2.orig.tar.gz: aria2-1.1.2/src/DHTPingMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTPingMessage.h"
#include "DHTNode.h"
#include "DHTConstants.h"
#include "DHTMessageDispatcher.h"
#include "DHTMessageFactory.h"
#include "DHTMessageCallback.h"
#include "bencode.h"

namespace aria2 {

const std::string DHTPingMessage::PING("ping");

DHTPingMessage::DHTPingMessage(const SharedHandle<DHTNode>& localNode,
			       const SharedHandle<DHTNode>& remoteNode,
			       const std::string& transactionID):
  DHTQueryMessage(localNode, remoteNode, transactionID) {}

DHTPingMessage::~DHTPingMessage() {}

void DHTPingMessage::doReceivedAction()
{
  // send back ping reply
  SharedHandle<DHTMessage> reply = _factory->createPingReplyMessage(_remoteNode, _localNode->getID(), _transactionID);
  _dispatcher->addMessageToQueue(reply);
}

bencode::BDE DHTPingMessage::getArgument()
{
  bencode::BDE aDict = bencode::BDE::dict();
  aDict[DHTMessage::ID] = bencode::BDE(_localNode->getID(), DHT_ID_LENGTH);
  return aDict;
}

std::string DHTPingMessage::getMessageType() const
{
  return PING;
}

void DHTPingMessage::validate() const {}

} // namespace aria2

==> aria2_1.25.0.orig.tar.gz: aria2-1.25.0/src/DHTPingMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTPingMessage.h"
#include "DHTNode.h"
#include "DHTConstants.h"
#include "DHTMessageDispatcher.h"
#include "DHTMessageFactory.h"
#include "DHTMessageCallback.h"
#include "DHTPingReplyMessage.h"

namespace aria2 {

const std::string DHTPingMessage::PING("ping");

DHTPingMessage::DHTPingMessage(const std::shared_ptr<DHTNode>& localNode,
                               const std::shared_ptr<DHTNode>& remoteNode,
                               const std::string& transactionID)
    : DHTQueryMessage(localNode, remoteNode, transactionID)
{
}

void DHTPingMessage::doReceivedAction()
{
  // send back ping reply
  getMessageDispatcher()->addMessageToQueue(
      getMessageFactory()->createPingReplyMessage(
          getRemoteNode(), getLocalNode()->getID(), getTransactionID()));
}

std::unique_ptr<Dict> DHTPingMessage::getArgument()
{
  auto aDict = Dict::g();
  aDict->put(DHTMessage::ID, String::g(getLocalNode()->getID(), DHT_ID_LENGTH));
  return aDict;
}

const std::string& DHTPingMessage::getMessageType() const { return PING; }

} // namespace aria2
